@@ -1,7 +1,8 @@
-# ClamTk, copyright (C) 2004-2021 Dave M
+# ClamTk, copyright (C) 2004-2024 Dave M
 #
 # This file is part of ClamTk
-# (https://gitlab.com/dave_m/clamtk/).
+# https://github.com/dave-theunsub/clamtk/
+# https://gitlab.com/dave_m/clamtk/
 #
 # ClamTk is free software; you can redistribute it and/or modify it
 # under the terms of either:
@@ -285,7 +286,12 @@ sub is_enabled {
         $min_spin_scan->set_value( $scan_minute );
         $scan_apply_btn->set_sensitive( FALSE );
         $scan_remove_btn->set_sensitive( TRUE );
-        $scan_status_label->set_text( _( 'A daily scan is scheduled' ) );
+
+        my $statement = _( 'A daily scan is scheduled' );
+        my ( $status_line_text )
+            = sprintf( "%s (%02d:%02d)", $statement, $scan_hour,
+            $scan_minute );
+        $scan_status_label->set_text( $status_line_text );
     } else {
         $scan_apply_btn->set_sensitive( TRUE );
         $scan_remove_btn->set_sensitive( FALSE );
@@ -463,6 +469,7 @@ sub apply_defs {
     my $full_cmd = $paths->{ freshclam };
 
     if (ClamTk::Prefs->get_preference( 'Update' ) eq 'single'
+
         # The following is necessary if the user is not root, as
         # the update attempt will fail due to lack of permissions.
         # It's still not a good fix since the user might not realize it...
@@ -506,6 +513,7 @@ sub apply_defs {
 }
 
 sub remove {
+
     # $which = 'clamtk-scan' or 'clamtk-defs'
     my ( $which ) = shift;
 
